:orphan:

********
Overview
********

.. start short_desc

**Utilities to manage Arrays**

.. end short_desc

The ``ut-arr`` package provides lightweight, static utility classes for
managing generic arrays (lists), arrays of arrays, arrays of dictionaries,
arrays of objects, and arrays of strings in Python.

All classes are purely static or class-method based and require no
instantiation.
